@@ -3,7 +3,7 @@ import zipfile
 from io import BytesIO
 from .tools import handle_abnormal
 from flask import Response, send_from_directory, make_response
-
+from urllib.parse import quote
 
 def download_file(file_path: str, file_name: str):
     if not os.path.exists(os.path.join(file_path, file_name)):
@@ -17,8 +17,10 @@ def download_file(file_path: str, file_name: str):
         file_name,  # 文件名(带扩展名)
         as_attachment=True
     ))
-    response.headers['Content-Disposition'] = 'attachment; filename={}'.format(
-        file_name.encode().decode('latin-1'))
+    # 确保文件名称包含中文，逗号等各种符号时均能正常响应
+    response.headers['Content-Disposition'] = "attachment; filename={0}; filename*=utf-8''{0}".format(
+        quote(file_name))
+
     return response
 
 
@@ -42,9 +44,9 @@ def download_flow(file_path: str, file_name: str):
 
     # 浏览器不识别的也会自动下载
     response = Response(send_file(), content_type='application/octet-stream')
-    # 确保中文格式不乱码
-    response.headers['Content-Disposition'] = 'attachment; filename={}'.format(
-        file_name.encode().decode('latin-1'))
+    # 确保文件名称包含中文，逗号等各种符号时均能正常响应
+    response.headers['Content-Disposition'] = "attachment; filename={0}; filename*=utf-8''{0}".format(
+        quote(file_name))
     return response
 
 
@@ -81,7 +83,7 @@ def download_directory(dir_path: str, zip_name: str, save_zip=False):
             z.write(data)
     # 浏览器不识别的也会自动下载
     response = Response(data, content_type='application/zip')
-    # 确保中文格式不乱码
-    response.headers['Content-Disposition'] = 'attachment; filename={}'.format(
-        zip_name.encode().decode('latin-1'))
+    # 确保文件名称包含中文，逗号等各种符号时均能正常响应
+    response.headers['Content-Disposition'] = "attachment; filename={0}; filename*=utf-8''{0}".format(
+        quote(zip_name))
     return response
